linux-6.18.7-sparky for Debian
-----------------------------

<This file describes information about the source package, see Debian policy
manual section 4.14. You WILL either need to modify or delete this file.>



 -- pavroo <pavroo@onet.eu>  Fri, 23 Jan 2026 15:32:49 +0100
